==> public-sdk-2.0.68-sources.jar: com/voxeet/sdk/core/AbstractVoxeetService.java <==
package com.voxeet.sdk.core;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.util.Log;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.voxeet.sdk.core.services.conference.information.ConferenceInformation;
import com.voxeet.sdk.core.services.holder.ServiceProviderHolder;

import org.greenrobot.eventbus.EventBus;

import java.io.IOException;

public abstract class AbstractVoxeetService<T> {

    private static final String TAG = AbstractVoxeetService.class.getSimpleName();

    @NonNull
    private ServiceProviderHolder<T> holder = ServiceProviderHolder.DEFAULT;

    /**
     * The Handler.
     */
    protected final static Handler handler = new Handler(Looper.getMainLooper());

    /**
     * The Context.
     */
    protected Context context;

    private AbstractVoxeetService() {

    }

    /**
     * Instantiates a new Voxeet service.
     *
     * @param instance      the voxeet parent instance
     * @param service_klass
     */
    protected AbstractVoxeetService(@NonNull VoxeetSdk instance, @Nullable Class<T> service_klass) {
        this(instance, new ServiceProviderHolder.Builder<T>()
                .setClient(instance.getClient())
                .setRetrofit(instance.getRetrofit())
                .setService(service_klass)
                .build());
    }

    /**
     * Instantiates a new Voxeet service.
     *
     * @param instance the instance of the SDK
     */
    protected AbstractVoxeetService(@NonNull VoxeetSdk instance, @NonNull ServiceProviderHolder<T> holder) {
        this();

        this.context = instance.getApplicationContext();

        this.holder = holder;
    }

    final protected T getService() {
        return holder.getService();
    }

    /**
     * Retrieves the error string from the request.
     *
     * @param e the exception
     * @return the error content
     */
    public String handleError(@Nullable Throwable e) {
        if(null == e) {
            return "invalid error";
        }
        Log.d(TAG, "handleError: " + e.getClass().getSimpleName());
        return e.getMessage();
    }

    /**
     * Gets error body.
     *
     * @param message the message
     * @return the error body
     */
    protected static VoxeetJsonError getErrorBody(String message) {
        ObjectMapper om = new ObjectMapper();
        VoxeetJsonError command = null;
        try {
            command = om.readValue(message, VoxeetJsonError.class);
        } catch (IOException e) {
            Log.e(TAG, "failed to get error body", e);
        }

        return command;
    }

    /**
     * Reset service.
     */
    public void resetService() {

    }


    /**
     * Get the current endpoint root url
     *
     * @param template
     * @return
     */
    @Nullable
    protected final String getURLRoot(@NonNull VoxeetSdk template) {
        return template.getVoxeetHttp().getBuiltServerUrl();
    }

    /**
     * @param template the token provider
     * @return the current token of the session
     */
    @Nullable
    protected final String getInternalToken(@NonNull VoxeetSdk template) {
        return template.getVoxeetHttp().getToken();
    }

    /**
     * @param template the token provider
     * @return the current token of the session
     */
    @Nullable
    protected final String getInternalJwtToken(@NonNull VoxeetSdk template) {
        return template.getVoxeetHttp().getJwtToken();
    }

    protected final VoxeetHttp getVoxeetHttp(VoxeetSdk template) {
        return template.getVoxeetHttp();
    }

    protected EventBus getEventBus() {
        return holder.getEventBus();
    }

    protected void registerEventBus() {
        EventBus eventBus = holder.getEventBus();
        if (!eventBus.isRegistered(this))
            eventBus.register(this);
    }

    protected void unRegisterEventBus() {
        EventBus eventBus = holder.getEventBus();
        if (eventBus.isRegistered(this))
            eventBus.unregister(this);
    }

    protected void postOnMainThread(@NonNull Runnable runnable) {
        handler.post(runnable);
    }
}

==> public-sdk-2.0.71.7-sources.jar: com/voxeet/sdk/core/AbstractVoxeetService.java <==
package com.voxeet.sdk.core;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.util.Log;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.voxeet.sdk.core.services.holder.ServiceProviderHolder;

import org.greenrobot.eventbus.EventBus;

import java.io.IOException;

public abstract class AbstractVoxeetService<T> {

    private static final String TAG = AbstractVoxeetService.class.getSimpleName();

    @NonNull
    private ServiceProviderHolder<T> holder = ServiceProviderHolder.DEFAULT;

    /**
     * The Handler.
     */
    protected final static Handler handler = new Handler(Looper.getMainLooper());

    /**
     * The Context.
     */
    protected Context context;

    private AbstractVoxeetService() {

    }

    /**
     * Instantiates a new Voxeet service.
     *
     * @param instance      the voxeet parent instance
     * @param service_klass
     */
    protected AbstractVoxeetService(@NonNull VoxeetSdk instance, @Nullable Class<T> service_klass) {
        this(instance, new ServiceProviderHolder.Builder<T>()
                .setClient(instance.getClient())
                .setRetrofit(instance.getRetrofit())
                .setService(service_klass)
                .build());
    }

    /**
     * Instantiates a new Voxeet service.
     *
     * @param instance the instance of the SDK
     */
    protected AbstractVoxeetService(@NonNull VoxeetSdk instance, @NonNull ServiceProviderHolder<T> holder) {
        this();

        this.context = instance.getApplicationContext();

        this.holder = holder;
    }

    final protected T getService() {
        return holder.getService();
    }

    /**
     * Retrieves the error string from the request.
     *
     * @param e the exception
     * @return the error content
     */
    public String handleError(@Nullable Throwable e) {
        if (null == e) {
            return "invalid error";
        }
        Log.d(TAG, "handleError: " + e.getClass().getSimpleName());
        return e.getMessage();
    }

    /**
     * Gets error body.
     *
     * @param message the message
     * @return the error body
     */
    protected static VoxeetJsonError getErrorBody(String message) {
        ObjectMapper om = new ObjectMapper();
        VoxeetJsonError command = null;
        try {
            command = om.readValue(message, VoxeetJsonError.class);
        } catch (IOException e) {
            Log.e(TAG, "failed to get error body", e);
        }

        return command;
    }

    /**
     * Reset service.
     */
    public void resetService() {

    }


    /**
     * Get the current endpoint root url
     *
     * @param template
     * @return
     */
    @Nullable
    protected final String getURLRoot(@NonNull VoxeetSdk template) {
        return template.getVoxeetHttp().getBuiltServerUrl();
    }

    /**
     * @param template the token provider
     * @return the current token of the session
     */
    @Nullable
    protected final String getInternalToken(@NonNull VoxeetSdk template) {
        return template.getVoxeetHttp().getToken();
    }

    /**
     * @param template the token provider
     * @return the current token of the session
     */
    @Nullable
    protected final String getInternalJwtToken(@NonNull VoxeetSdk template) {
        return template.getVoxeetHttp().getJwtToken();
    }

    protected final VoxeetHttp getVoxeetHttp(VoxeetSdk template) {
        return template.getVoxeetHttp();
    }

    protected EventBus getEventBus() {
        return holder.getEventBus();
    }

    protected void registerEventBus() {
        EventBus eventBus = holder.getEventBus();
        try {
            if (!eventBus.isRegistered(this))
                eventBus.register(this);
        } catch (Exception e) {
            Log.d(TAG, "registerEventBus: logging for debug purposes :");
            e.printStackTrace();
        }
    }

    protected void unRegisterEventBus() {
        EventBus eventBus = holder.getEventBus();
        try {
            if (eventBus.isRegistered(this))
                eventBus.unregister(this);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    protected void postOnMainThread(@NonNull Runnable runnable) {
        handler.post(runnable);
    }
}
